@@ -12,7 +12,7 @@ Test::File::Contents - Test routines for examining the contents of files
 
 =cut
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Test::Builder;
 use Digest::MD5;
@@ -455,24 +455,25 @@ sub _resolve {
 
 =item * Kirrily Robert <skud@cpan.org>
 
-=item * David E. Wheeler <david@kineticode.com>
+=item * David E. Wheeler <david@justatheory.com>
 
 =back
 
 =head1 Support
 
 This module is stored in an open L<GitHub
-repository|http://github.com/theory/test-file-contents/tree/>. Feel free to
-fork and contribute!
+repository|https://github.com/theory/test-file-contents/>. Feel free to fork
+and contribute!
 
 Please file bug reports via L<GitHub
-Issues|http://github.com/theory/test-file-contents/issues/> or by sending mail to
+Issues|https://github.com/theory/test-file-contents/issues/> or by sending
+mail to
 L<bug-Test-File-Contents@rt.cpan.org|mailto:bug-Test-File-Contents@rt.cpan.org>.
 
 =head1 Copyright and License
 
 Copyright (c) 2004-2007 Kirrily Robert. Some Rights Reserved.
-Copyright (c) 2007-2011 David E. Wheeler. Some Rights Reserved.
+Copyright (c) 2007-2016 David E. Wheeler. Some Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
